..
    This file is automatically generated. Do not make
    changes as these will be overwritten. Rather edit
    the docstrings in the source code.

``yaff.conversion`` -- Conversion of external trajectory data
#############################################################




``yaff.conversion.common`` -- Tools for writing trajectory data
===============================================================

.. automodule:: yaff.conversion.common
    :members:


``yaff.conversion.cp2k`` -- CP2K Files
======================================

.. automodule:: yaff.conversion.cp2k
    :members:


``yaff.conversion.dlpoly`` -- DLPOLY Files
==========================================

.. automodule:: yaff.conversion.dlpoly
    :members:


``yaff.conversion.gaussian`` -- Gaussian09 BOMD log Files
=========================================================

.. automodule:: yaff.conversion.gaussian
    :members:


``yaff.conversion.xyz`` -- XYZ Files
====================================

.. automodule:: yaff.conversion.xyz
    :members:
